# Release Notes
---

# [1.2.0](https://github.com/osl-incubator/makim/compare/1.1.1...1.2.0) (2023-02-03)


### Features

* Add initial support for arguments ([#11](https://github.com/osl-incubator/makim/issues/11)) ([4d105d0](https://github.com/osl-incubator/makim/commit/4d105d0b6b1488af298877f8c0e9390256c5b559))

## [1.1.1](https://github.com/osl-incubator/makim/compare/1.1.0...1.1.1) (2023-02-03)


### Bug Fixes

* Fix release workflow ([#10](https://github.com/osl-incubator/makim/issues/10)) ([39146bb](https://github.com/osl-incubator/makim/commit/39146bb3946661c9630b1ad2bceb7eae297fbad5))

# [1.1.0](https://github.com/osl-incubator/makim/compare/1.0.2...1.1.0) (2023-02-03)


### Features

* Add support for variables for the target group ([#9](https://github.com/osl-incubator/makim/issues/9)) ([e3aa389](https://github.com/osl-incubator/makim/commit/e3aa389a07b7f5677328420f1389e84ed71bc7b3))

## [1.0.2](https://github.com/osl-incubator/makim/compare/1.0.1...1.0.2) (2023-01-26)


### Bug Fixes

* Fix support for Python 3.7.1, 3.8, 3.9, 3.10 ([#7](https://github.com/osl-incubator/makim/issues/7)) ([418f3de](https://github.com/osl-incubator/makim/commit/418f3de6dc4e5f1b963b32da9736163ea78ce5f5))

## [1.0.1](https://github.com/osl-incubator/makim/compare/1.0.0...1.0.1) (2023-01-25)


### Bug Fixes

* Suppress the sh traceback message error ([#5](https://github.com/osl-incubator/makim/issues/5)) ([dc3f4ad](https://github.com/osl-incubator/makim/commit/dc3f4ad1a949cd72e628742107cf5bd368721b7e))
